API Reference
=============

This section contains the API reference for all public modules in the `canopy` package. Each entry links to the documentation for that module, automatically generated using `autodoc`.

.. toctree::
   :maxdepth: 2

   source/canopy.core
   source/canopy.grid
   source/canopy.json
   source/canopy.plotting
   source/canopy.readers
   source/canopy.source_data
   source/canopy.sources
   source/canopy.util
   source/canopy.visualization